package com.example.wc24h;

import android.app.Dialog;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.Button;
import android.widget.ListView;
import android.widget.TextView;

import java.util.ArrayList;

class SelectionDialog extends Dialog
{
    private MainActivity        mContext        = null;
    private ListView            list;
    SelectionListAdapter        listAdapter;
    TextView                    title;
    Button                      select_btn;
    Button                      cancel_btn;

    interface SelectionDialogListener {
        void buttonPressed(int selected);
    }

    SelectionDialog(MainActivity a)
    {
        super(a, R.style.dialog_custom_style);

        mContext = a;
        setContentView(R.layout.selection_list_dialog);

        title = (TextView)findViewById(R.id.title);
        select_btn = (Button)findViewById(R.id.select_button);
        cancel_btn = (Button)findViewById(R.id.cancel_button);
        cancel_btn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                dismiss();
            }
        });

        list = (ListView)findViewById(R.id.list);
        listAdapter = new SelectionListAdapter(mContext);
        list.setAdapter(listAdapter);
        list.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView, View view, int position, long id) {
                Log.w("WC24h", listAdapter.getItem(position));
                listAdapter.selected = position;
                listAdapter.notifyDataSetChanged();
            }
        });

    }

    void setCancelListener(final SelectionDialogListener l) {
        if (l != null) {
            cancel_btn.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    l.buttonPressed(listAdapter.selected);
                }
            });
        }
    }

    void setSelectedListener(final SelectionDialogListener l) {
        if (l != null) {
            select_btn.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View view) {
                    l.buttonPressed(listAdapter.selected);
                }
            });
        }
    }

    void setDialogTitle(int id) {
        title.setText(mContext.getString(R.string.select_animation, mContext.getString(id)));
    }

    void setSelections(ArrayList<String> data) {
        listAdapter.clear();
        for (String str: data) {
            listAdapter.add(str);
        }
        listAdapter.notifyDataSetInvalidated();
    }

    void setSelected(int selected) {
        listAdapter.selected = selected;
        listAdapter.notifyDataSetChanged();
        list.setSelection(selected);
    }

    @Override
    protected void onStart()
    {
        super.onStart();
    }

    @Override
    protected void onStop()
    {
        super.onStop();
    }
}